<?php
$t = [
    'html_lang' => 'fr',
    'panel_description' => 'Panneau de gestion IPTV',
    'login_title' => 'Connexion',
    'welcome_back' => 'Bienvenue',
    'login_prompt' => 'Veuillez vous connecter pour continuer.',
    'username' => 'Nom d\'utilisateur',
    'username_placeholder' => 'Entrez votre nom d\'utilisateur',
    'password' => 'Mot de passe',
    'password_placeholder' => 'Entrez votre mot de passe',
    'keep_signed_in' => 'Rester connecté',
    'login_button' => 'Se connecter',
    'login_success' => 'Connexion réussie !',
    'login_error' => 'Identifiants invalides.'
];
?>
