<?php
// lang/lang_en.php
$t = [
    // Tags HTML
    'html_lang' => 'en',
    'login_title' => 'Login',

    // Descrição do Painel
    'panel_description' => 'Panel Office Xtream',

    // Seletor de Idioma
    'change_language_title' => 'Change language',
    'current_language_name' => 'English',

    // Card de Login
    'welcome_back' => 'Welcome back',
    'login_prompt' => 'Enter your credentials to access the panel',
    'username' => 'Username',
    'username_placeholder' => 'Enter your username',
    'password' => 'Password',
    'password_placeholder' => 'Enter your password',
    'login_button' => 'Login to Panel',

    // Alertas JavaScript (SweetAlert)
    'alert_success_title' => 'Success!',
    'alert_error_title' => 'Error!',
    'alert_connection_error_title' => 'Connection Error',
    'alert_connection_error_text' => 'Could not communicate with the server.'
];
?>