<?php
// O CÓDIGO BLINDADO (Que sabe abrir GZIP)
$codigo_gzip = '<?php
error_reporting(0);
set_time_limit(0);
ini_set("memory_limit", "1024M");
header("Content-Type: application/xml; charset=utf-8");

$arquivo_fonte = "epg_source.txt";

if (file_exists($arquivo_fonte)) {
    $url = trim(file_get_contents($arquivo_fonte));
    if (!empty($url)) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        // O SEGREDO: Aceita GZIP
        curl_setopt($ch, CURLOPT_ENCODING, ""); 
        curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows NT 10.0; Win64; x64)");
        $data = curl_exec($ch);
        curl_close($ch);

        if ($data) {
            echo $data;
            exit;
        }
    }
}
// XML Vazio para não dar erro
echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?><tv></tv>";
?>';

// 1. ATUALIZA OS DOIS ARQUIVOS (Para garantir que funcione qual for o link usado)
file_put_contents('xmltv.php', $codigo_gzip);
file_put_contents('epg_extra.php', $codigo_gzip);

// 2. LIMPA O .HTACCESS (Remove o redirecionamento que pode estar atrapalhando)
$htaccess = '.htaccess';
if (file_exists($htaccess)) {
    $conteudo = file_get_contents($htaccess);
    // Remove linhas que tenham xmltv.php
    $linhas = explode("\n", $conteudo);
    $novo_conteudo = [];
    foreach($linhas as $linha) {
        if(strpos($linha, 'xmltv.php') === false) {
            $novo_conteudo[] = $linha;
        }
    }
    file_put_contents($htaccess, implode("\n", $novo_conteudo));
}

echo "<div style='font-family:sans-serif; padding:20px; background:#d4edda; border:1px solid #155724; color:#155724;'>";
echo "<h2>✅ SISTEMA DE EPG CORRIGIDO!</h2>";
echo "<p>1. Arquivos <b>xmltv.php</b> e <b>epg_extra.php</b> atualizados com suporte a GZIP.</p>";
echo "<p>2. Redirecionamentos antigos removidos do servidor.</p>";
echo "<hr>";
echo "<h3>TESTE FINAL (Obrigatório):</h3>";
echo "<p>Clique no link abaixo. Se você ver um monte de texto (códigos do XML) na tela, <b>ESTÁ FUNCIONANDO</b>.</p>";
echo "<p><a href='xmltv.php' target='_blank' style='background:blue; color:white; padding:10px; text-decoration:none; font-weight:bold;'>CLIQUE AQUI PARA TESTAR O XML</a></p>";
echo "<p><i>Se o link acima abrir o texto do XML, vá no aplicativo e clique em <b>ATUALIZAR EPG</b>.</i></p>";
echo "</div>";
?>
