<?php
$t = [
    'html_lang' => 'de',
    'panel_description' => 'IPTV-Verwaltungspanel',
    'login_title' => 'Anmeldung',
    'welcome_back' => 'Willkommen zurück',
    'login_prompt' => 'Bitte melden Sie sich an, um fortzufahren.',
    'username' => 'Benutzername',
    'username_placeholder' => 'Geben Sie Ihren Benutzernamen ein',
    'password' => 'Passwort',
    'password_placeholder' => 'Geben Sie Ihr Passwort ein',
    'keep_signed_in' => 'Angemeldet bleiben',
    'login_button' => 'Anmelden',
    'login_success' => 'Erfolgreich eingeloggt!',
    'login_error' => 'Ungültige Anmeldeinformationen.'
];
?>
