<?php
// lang/lang_pt.php
$t = [
    // Tags HTML
    'html_lang' => 'pt-BR',
    'login_title' => 'Login',

    // Descrição do Painel
    'panel_description' => 'Panel Office Xtream',

    // Seletor de Idioma
    'change_language_title' => 'Mudar idioma',
    'current_language_name' => 'Português',

    // Card de Login
    'welcome_back' => 'Bem-vindo de volta',
    'login_prompt' => 'Entre com suas credenciais para acessar o painel',
    'username' => 'Usuário',
    'username_placeholder' => 'Digite seu usuário',
    'password' => 'Senha',
    'password_placeholder' => 'Digite sua senha',
    'login_button' => 'Entrar no Painel',

    // Alertas JavaScript (SweetAlert)
    'alert_success_title' => 'Sucesso!',
    'alert_error_title' => 'Erro!',
    'alert_connection_error_title' => 'Erro de Conexão',
    'alert_connection_error_text' => 'Não foi possível se comunicar com o servidor.'
];
?>