<?php
$host = 'localhost';
$db   = 'geanrober_kOfficePanel';
$user = 'geanrober_kOfficePanel'; // Seu usuário do MySQL
$pass = 'Jean#909110';     // Sua senha do MySQL

try {
    $pdo = new PDO("mysql:host=$host;dbname=$db;charset=utf8", $user, $pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Erro na conexão com banco de dados: " . $e->getMessage());
}
?>